==> nicoapi-0.2.zip: nicoapi-0.2/src/nicoapi.py <==
"""
 02/04/2008 takeyan<techlabo.py@gmail.com>
 
 Python API Project for the Nico Nico Douga

 This code is a prototype.
 Please help if the project is accepted.

 General Public License.
"""

import urllib,urllib2,cookielib
import MultipartPostHandler
import re,sys,os
from types import *

from xml.dom.minidom import parseString

class nicoapi():
	def login_s(self,myac,pw,*ua):
		url = "https://secure.nicovideo.jp/secure/login"
		post_data = {'site' : "smile",'mail' : myac,'password' : pw}
		cookie = cookielib.CookieJar()
		opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cookie),MultipartPostHandler.MultipartPostHandler)
		# HTTP-HEADER
		opener.addheaders = [('Referer','http://www.smilevideo.jp/')]
		if ua:
			opener.addheaders = [('User-agent',ua)]
		else:
			opener.addheaders = [('User-agent','Mozilla/4.0 (compatible; MSIE 6.0; Linux)')]
		# LOGIN
		opener.open(url, post_data)
		return opener
		
	def upmov(self,opener,filename,scr):
		# FILE IS SENT
		url2 = "http://www.smilevideo.jp/upload"
		post_file = {'cmd' : "upload",'filename' : open(filename, "rb"),'screen' : str(scr)}
		read = opener.open(url2, post_file)
		return read
	
	def getThumbnail_url(self,id):
		sm = re.compile("sm")
		url = "http://tn-skr.smilevideo.jp/smile?i="
		if isinstance(id, ListType):
			all = []
			for list in id:
				all.append(url+sm.sub("",list))
			return all
		elif isinstance(id, StringType):
			return url+sm.sub("",id)

	def login_n(self,myac,pw,*ua):
		url = "https://secure.nicovideo.jp/secure/login?site=niconico"
		post_data = {'next_url' : "",'mail' : myac,'password' : pw}
		cookie = cookielib.CookieJar()
		opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cookie),MultipartPostHandler.MultipartPostHandler)
		# HTTP-HEADER
		opener.addheaders = [('Referer','http://www.smilevideo.jp/')]
		if ua:
			opener.addheaders = [('User-agent',ua)]
		else:
			opener.addheaders = [('User-agent','Mozilla/4.0 (compatible; MSIE 6.0; Linux)')]
		# LOGIN
		opener.open(url, post_data)
		return opener

	def getFlv(self,opener,id,filepath):
		apiurl = "http://www.nicovideo.jp/api/getflv/"
		api = opener.open(apiurl+id).read()
		get_path = re.compile("(&link).*").sub("",re.compile(".*(&url=)").sub("",api))
		print get_path
		url_parm = "http://www.nicovideo.jp/watch/"+id
		opener.open(url_parm).read()
		dat = opener.open(urllib.unquote(get_path)).read()
		fw = open(filepath, "wb")
		fw.write(dat)
		fw.close
	def getThumbnail(self,id,dir):
		opener = urllib2.build_opener()
		opener.addheaders = [('Referer','http://smilevideo.jp')]
		opener.addheaders = [('User-agent','Mozilla/4.0 (compatible; MSIE 6.0; Linux)')]
		thumburl = self.getThumbnail_url(id)
		if isinstance(thumburl, ListType):
			for url in thumburl:
				id = re.compile(".*(\?i=)").sub("",url)
				id = "sm"+id
				if not re.match(re.compile(r"/"),dir):
					dir = dir+"/"
				fw = open(dir+id+".jpg","wb")
				fw.write(opener.open(url).read())
				fw.close()
				print id+".jpg",">",dir
		elif isinstance(thumburl, StringType):
			id = re.compile(".*(\?i=)").sub("",thumburl)
			id = "sm"+id
			if not re.search(re.compile("/$"),dir):
				dir = dir+"/"
			fw = open(dir+id+".jpg","wb")
			fw.write(opener.open(thumburl).read())
			fw.close()
			print id+".jpg",">",dir
	def getRankRss(self,mode,*category):
		"""
		mylist = http://www.nicovideo.jp/ranking/mylist/daily/all?rss=rss
		res = http://www.nicovideo.jp/ranking/res/daily/all?rss=rss
		view = http://www.nicovideo.jp/ranking/view/daily/all?rss=rss
		ichiba = http://www.nicovideo.jp/ranking/all/daily/ichiba?rss=rss
		"""
		if mode == "mylist":
			rss = "http://www.nicovideo.jp/ranking/mylist/daily/all?rss=rss"
		elif mode == "res":
			rss = "http://www.nicovideo.jp/ranking/res/daily/all?rss=rss"
		elif mode == "view":
			rss = "http://www.nicovideo.jp/ranking/view/daily/all?rss=rss"
		elif mode == "ichiba":
			rss = "http://www.nicovideo.jp/ranking/all/daily/ichiba?rss=rss"
		if category:
			print "The argument 'category' is not supported. "
			if mode == "mylist":
				rss = "http://www.nicovideo.jp/ranking/mylist/daily/"+str(category)+"?rss=rss"
			elif mode == "res":
				rss = "http://www.nicovideo.jp/ranking/res/daily/"+str(category)+"?rss=rss"
			elif mode == "view":
				rss = "http://www.nicovideo.jp/ranking/view/daily/"+str(category)+"rss=rss"
			elif mode == "ichiba":
				rss = "http://www.nicovideo.jp/ranking/all/daily/ichiba?rss=rss"
		title,link = parse().rank_rss(urllib.urlopen(rss).read())
		return title,link
	def getNewRss(self):
		rss = "http://www.nicovideo.jp/newarrival?rss=rss"
		title,link = parse().rank_rss(urllib.urlopen(rss).read())
		return title,link

class parse():
	def getText(self,element):
			nodelist = element.childNodes
			small = ""
			for node in nodelist:
				small = small+node.data
			return small

	def rank_rss(self,body):
		dom = parseString(body)
		element = dom.documentElement
		title,link = self.parse_one(element)
		return title,link

	def parse_one(self,element):
		i = 0
		title = []
		link = []
		for tmp in element.getElementsByTagName("title"):
			title.append(self.getText(element.getElementsByTagName("title")[i]))
			link.append(self.getText(element.getElementsByTagName("link")[i]))
			i += 1
		return title, link

==> nicoapi-0.3.zip: nicoapi-0.3/src/nicoapi.py <==
#encoding: utf-8

"""
 02/04/2008 takeyan<techlabo.py@gmail.com>
 
 Python API Project for the Nico Nico Douga

 This code is a prototype.
 Please help if the project is accepted.

 General Public License.
"""

import urllib,urllib2,cookielib
import MultipartPostHandler
import re,sys,os,time
from types import *

from xml.dom.minidom import parseString

class nicoapi():
	def login_s(self,myac,pw,*ua):
		url = "https://secure.nicovideo.jp/secure/login"
		post_data = {'site' : "smile",'mail' : myac,'password' : pw}
		cookie = cookielib.CookieJar()
		opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cookie),MultipartPostHandler.MultipartPostHandler)
		# HTTP-HEADER
		opener.addheaders = [('Referer','http://www.smilevideo.jp/')]
		if ua:
			opener.addheaders = [('User-agent',ua)]
		else:
			opener.addheaders = [('User-agent','Mozilla/4.0 (compatible; MSIE 6.0; Linux)')]
		# LOGIN
		opener.open(url, post_data)
		return opener
		
	def upmov(self,opener,filename,scr,movtitle,movdit,category):
		# FILE IS SENT
		url = "http://www.smilevideo.jp/"
		url2 = "http://www.smilevideo.jp/upload"
		post_file = {'cmd' : "upload",'filename' : open(filename, "rb"),'screen' : str(scr)}
		read = opener.open(url2, post_file)
		while 1:
			body = opener.open(url).read()
			if re.search("fileid", body):
				body = re.compile('\n').sub("",body)
				body = re.compile('.*(name="fileid" value=")').sub("",body)
				id = re.compile('(").*').sub("",body)
				post_dt = {'cmd' : "edit",'thumbnail' : "0",'movie_title' : movtitle,'movie_detail' : movdit,'tags1' : category,'hide_flag' : "0",'submitbtn' : "1",'fileid' : id,'f' : id}
				print opener.open(url,post_dt).read(), id
				break
			print "Now encoding..."
			time.sleep(10)
		return
	
	def getThumbnail_url(self,id):
		sm = re.compile("sm")
		url = "http://tn-skr.smilevideo.jp/smile?i="
		if isinstance(id, ListType):
			all = []
			for list in id:
				all.append(url+sm.sub("",list))
			return all
		elif isinstance(id, StringType):
			return url+sm.sub("",id)

	def login_n(self,myac,pw,*ua):
		url = "https://secure.nicovideo.jp/secure/login?site=niconico"
		post_data = {'next_url' : "",'mail' : myac,'password' : pw}
		cookie = cookielib.CookieJar()
		opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cookie),MultipartPostHandler.MultipartPostHandler)
		# HTTP-HEADER
		opener.addheaders = [('Referer','http://www.smilevideo.jp/')]
		if ua:
			opener.addheaders = [('User-agent',ua)]
		else:
			opener.addheaders = [('User-agent','Mozilla/4.0 (compatible; MSIE 6.0; Linux)')]
		# LOGIN
		opener.open(url, post_data)
		return opener

	def getFlv(self,opener,id,filepath):
		apiurl = "http://www.nicovideo.jp/api/getflv/"
		api = opener.open(apiurl+id).read()
		get_path = re.compile("(&link).*").sub("",re.compile(".*(&url=)").sub("",api))
		url_parm = "http://www.nicovideo.jp/watch/"+id
		opener.open(url_parm).read()
		dat = opener.open(urllib.unquote(get_path)).read()
		try:
			print id,"download."
			fw = open(filepath, "wb")
			fw.write(dat)
			fw.close()
		except:
			print "Error: Failed to Save."
		return id

	def getFlvs(self,opener,idlist,dirpath):
		apiurl = "http://www.nicovideo.jp/api/getflv/"
		for id in idlist:
			api = opener.open(apiurl+id).read()
			get_path = re.compile("(&link).*").sub("",re.compile(".*(&url=)").sub("",api))
			url_parm = "http://www.nicovideo.jp/watch/"+id
			opener.open(url_parm).read()
			dat = opener.open(urllib.unquote(get_path)).read()
			try:
				print id,"download."
				fw = open(dirpath+id+".flv", "wb")
				fw.write(dat)
				fw.close()
			except:
				print "Error: Failed to Save."
		return id

	def getThumbnail(self,id,dir):
		opener = urllib2.build_opener()
		opener.addheaders = [('Referer','http://smilevideo.jp')]
		opener.addheaders = [('User-agent','Mozilla/4.0 (compatible; MSIE 6.0; Linux)')]
		thumburl = self.getThumbnail_url(id)
		if isinstance(thumburl, ListType):
			for url in thumburl:
				id = re.compile(".*(\?i=)").sub("",url)
				id = "sm"+id
				if not re.match(re.compile(r"/"),dir):
					dir = dir+"/"
				try:
					fw = open(dir+id+".jpg","wb")
					fw.write(opener.open(url).read())
					fw.close()
					print id+".jpg",">",dir
				except:
					print "Error: Failed to Save."
		elif isinstance(thumburl, StringType):
			id = re.compile(".*(\?i=)").sub("",thumburl)
			id = "sm"+id
			if not re.search(re.compile("/$"),dir):
				dir = dir+"/"
			try:
				fw = open(dir+id+".jpg","wb")
				fw.write(opener.open(thumburl).read())
				fw.close()
				print id+".jpg",">",dir
			except:
				print "Error: Failed to Save."
		return id

	def getRankRss(self,mode,*category):
		"""
		mylist = http://www.nicovideo.jp/ranking/mylist/daily/all?rss=rss
		res = http://www.nicovideo.jp/ranking/res/daily/all?rss=rss
		view = http://www.nicovideo.jp/ranking/view/daily/all?rss=rss
		ichiba = http://www.nicovideo.jp/ranking/all/daily/ichiba?rss=rss
		"""
		if mode == "mylist":
			rss = "http://www.nicovideo.jp/ranking/mylist/daily/all?rss=rss"
		elif mode == "res":
			rss = "http://www.nicovideo.jp/ranking/res/daily/all?rss=rss"
		elif mode == "view":
			rss = "http://www.nicovideo.jp/ranking/view/daily/all?rss=rss"
		elif mode == "ichiba":
			rss = "http://www.nicovideo.jp/ranking/all/daily/ichiba?rss=rss"
		if category:
			print "The argument 'category' is not supported. "
			if mode == "mylist":
				rss = "http://www.nicovideo.jp/ranking/mylist/daily/"+str(category)+"?rss=rss"
			elif mode == "res":
				rss = "http://www.nicovideo.jp/ranking/res/daily/"+str(category)+"?rss=rss"
			elif mode == "view":
				rss = "http://www.nicovideo.jp/ranking/view/daily/"+str(category)+"rss=rss"
			elif mode == "ichiba":
				rss = "http://www.nicovideo.jp/ranking/all/daily/ichiba?rss=rss"
		title,link = parse().rank_rss(urllib.urlopen(rss).read())
		return title,link

	def getNewRss(self):
		rss = "http://www.nicovideo.jp/newarrival?rss=rss"
		title,link = parse().rank_rss(urllib.urlopen(rss).read())
		return title,link

class parse():
	def getText(self,element):
			nodelist = element.childNodes
			small = ""
			for node in nodelist:
				small = small+node.data
			return small

	def rank_rss(self,body):
		dom = parseString(body)
		element = dom.documentElement
		title,link = self.parse_one(element)
		return title,link

	def parse_one(self,element):
		i = 0
		title = []
		link = []
		for tmp in element.getElementsByTagName("title"):
			title.append(self.getText(element.getElementsByTagName("title")[i]))
			link.append(self.getText(element.getElementsByTagName("link")[i]))
			i += 1
		return title, link
